@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.2.1';
+our $VERSION = '1.2.2';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -8,20 +8,23 @@ use POSIX ();
 use Carp ();
 use base qw(Mojo::Weixin::Util Mojo::Weixin::Model Mojo::Weixin::Client Mojo::Weixin::Plugin Mojo::Weixin::Request);
 
-has http_debug          => 0;
+has http_debug          => sub{$ENV{MOJO_WEIXIN_HTTP_DEBUG} || 0 } ;
 has ua_debug            => sub{$_[0]->http_debug};
 has ua_debug_req_body   => sub{$_[0]->ua_debug};
 has ua_debug_res_body   => sub{$_[0]->ua_debug};
 has log_level           => 'info';     #debug|info|warn|error|fatal
 has log_path            => undef;
 has log_encoding        => undef;      #utf8|gbk|...
+has log_head            => undef;
+has log_unicode         => 0;
 
-has account             => 'default';
+has account             => sub{ $ENV{MOJO_WEIXIN_ACCUNT} || 'default'};
 has start_time          => time;
-has tmpdir              => sub {File::Spec->tmpdir();};
+has tmpdir              => sub {$ENV{MOJO_WEIXIN_TMPDIR} || File::Spec->tmpdir();};
 has media_dir           => sub {$_[0]->tmpdir};
 has cookie_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_cookie_',$_[0]->account || 'default','.dat'))};
 has qrcode_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_qrcode_',$_[0]->account || 'default','.jpg'))};
+has pid_path            => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_pid_',$_[0]->account || 'default','.pid'))};
 has ioloop              => sub {Mojo::IOLoop->singleton};
 has keep_cookie         => 1;
 has fix_media_loop      => 1;
@@ -37,24 +40,28 @@ has data    => sub {+{}};
 has version => $Mojo::Weixin::VERSION;
 has plugins => sub{+{}};
 has log     => sub{
+    my $self = $_[0];
     Mojo::Weixin::Log->new(
         encoding    =>  $_[0]->log_encoding,
         path        =>  $_[0]->log_path,
         level       =>  $_[0]->log_level,
+        unicode_support => $_[0]->log_unicode,
         format      =>  sub{
             my ($time, $level, @lines) = @_;
             my $title = "";
+            my $head  = $self->log_head || "";
             if(ref $lines[0] eq "HASH"){
                 my $opt = shift @lines; 
                 $time = $opt->{"time"} if defined $opt->{"time"};
-                $title = $opt->{title} . " " if defined $opt->{"title"};
-                $level  = $opt->{level} if defined $opt->{"level"};
+                $title = $opt->{"title"} . " " if defined $opt->{"title"};
+                $level  = $opt->{"level"} if defined $opt->{"level"};
+                $head  = $opt->{"head"} if defined $opt->{"head"};
             }
             @lines = split /\n/,join "",@lines;
             my $return = "";
             $time = $time?POSIX::strftime('[%y/%m/%d %H:%M:%S]',localtime($time)):"";
             $level = $level?"[$level]":"";
-            for(@lines){$return .= $time . " " . $level . " " . $title . $_ . "\n";}
+            for(@lines){$return .= $head . $time . " " . $level . " " . $title . $_ . "\n";}
             return $return;
         }
     )
@@ -98,7 +105,7 @@ has _synccheck_running => 0;
 has _synccheck_error_count => 0;
 has _synccheck_connection_id => undef;
 
-sub deviceid { return "e" . substr(rand . ("0" x 15),2,15);}
+sub deviceid { return "e" . substr(rand() . ("0" x 15),2,15);}
 sub on {
     my $self = shift;
     my @return;
@@ -147,8 +154,18 @@ sub new {
     my $class = shift;
     my $self  = $class->SUPER::new(@_);
     #$ENV{MOJO_USERAGENT_DEBUG} = $self->{ua_debug};
+    
+    for my $env(keys %ENV){
+        if($env=~/^MOJO_WEIXIN_([A-Z_]+)$/){
+            my $attr = lc $1;
+            next if $attr =~ /^plugin_/;
+            $self->$attr($ENV{$env}) if $self->can($attr);
+        }
+    }
+
     $self->info("当前正在使用 Mojo-Weixin v" . $self->version);
     $self->ioloop->reactor->on(error=>sub{
+        return;
         my ($reactor, $err) = @_;
         $self->error("reactor error: " . Carp::longmess($err));
     });
@@ -157,6 +174,14 @@ sub new {
         my ($self, $err) = @_;
         $self->error(Carp::longmess($err));
     });
+    $self->check_pid();
+    $SIG{CHLD} = 'IGNORE';
+    $SIG{INT} = $SIG{KILL} = $SIG{TERM} = $SIG{HUP} = sub{
+        $self->info("正在停止客户端...");
+        $self->clean_qrcode();
+        $self->clean_pid();
+        $self->stop();
+    };
     $self->on(qrcode_expire=>sub{
         my($self) = @_;
         my $count = $self->qrcode_count;
