@@ -333,10 +333,7 @@ sub _parse_sync_data {
                     $msg->{app_url} = $dom->at('msg > appmsg > url')->content;
                     $msg->{app_name} = $dom->at('msg > appinfo > appname')->content;
                     for( ($msg->{app_title},$msg->{app_desc},$msg->{app_url},$msg->{app_name}) ){
-                        if($_=~/^<!\[CDATA\[.*\]\]>$/){
-                            s/^<!\[CDATA\[//g;
-                            s/\]\]>//g;
-                        }
+                        s/!\[CDATA\[(.*?)\]\]/$1/g;
                     }
                     $msg->{app_url} = Mojo::Util::html_unescape($msg->{app_url});
                     $msg->{content} = "[应用分享]标题：@{[$msg->{app_title} || '未知']}\n[应用分享]描述：@{[$msg->{app_desc} || '未知']}\n[应用分享]应用：@{[$msg->{app_name} || '未知']}\n[应用分享]链接：@{[$msg->{app_url} || '未知']}";
