@@ -2,6 +2,7 @@ package Mojo::Weixin::Plugin::Openwx;
 our $PRIORITY = 98;
 use strict;
 use Encode;
+use POSIX qw();
 use Mojo::Util qw();
 use Mojo::Weixin::Server;
 my $server;
@@ -190,6 +191,7 @@ sub call{
     get '/openwx/get_group_info'    => sub {$_[0]->render(json=>[map {$_->to_json_hash()} @{$client->group}]); };
     any [qw(GET POST)] => '/openwx/search_friend' => sub{
         my $c = shift;
+        $c->req->params->remove('client');
         my @params = map {defined $_?Encode::encode("utf8",$_):$_} @{$c->req->params->pairs};
         my @objects = $client->search_friend(@params);
         if(@objects){
@@ -201,6 +203,7 @@ sub call{
     };
     any [qw(GET POST)] => '/openwx/search_group' => sub{
         my $c = shift;
+        $c->req->params->remove('client');
         my @params = map {defined $_?Encode::encode("utf8",$_):$_} @{$c->req->params->pairs};
         my @objects = $client->search_group(@params);
         if(@objects){
@@ -543,6 +546,10 @@ sub call{
             $c->render_later;
             $object->get_avatar(sub{
                 my ($path,$data,$mime) = @_;
+                my $mtime = time;
+                $c->res->headers->cache_control('max-age=3600');
+                $c->res->headers->expires(POSIX::strftime("%a, %d %b %Y %H:%M:%S GMT",gmtime($mtime+3600)));
+                $c->res->headers->last_modified(POSIX::strftime("%a, %d %b %Y %H:%M:%S GMT",gmtime($mtime)));
                 $c->res->headers->content_type($mime || 'image/jpg');
                 $c->render(data=>$data,);  
             });
