@@ -1,7 +1,6 @@
 package Mojo::Weixin::User;
 use Mojo::Weixin::Base 'Mojo::Weixin::Model::Base';
 has [qw(
-    avatar    
     name
     account
     province
@@ -11,8 +10,15 @@ has [qw(
     signature
     display
     markname
+    _avatar    
 )];
 
+sub new {
+    my $self = shift;
+    $self = $self->Mojo::Weixin::Base::new(@_);
+    $self->client->emoji_convert(\$self->{name},$self->client->emoji_to_text);
+    $self;
+}
 sub get_avatar{
     my $self = shift;
     $self->client->get_avatar($self,@_);
@@ -28,6 +34,7 @@ sub update{
     my $hash = shift;
     for(grep {substr($_,0,1) ne "_"} keys %$self){
         if(exists $hash->{$_}){
+            $self->client->emoji_convert(\$hash->{$_},$self->client->emoji_to_text) if $_ eq "name";
             if(defined $hash->{$_} and defined $self->{$_}){
                 if($hash->{$_} ne $self->{$_}){
                     my $old_property = $self->{$_};
